aboutsummaryrefslogtreecommitdiffstats
path: root/gtk/h225_counter.c
diff options
context:
space:
mode:
Diffstat (limited to 'gtk/h225_counter.c')
-rw-r--r--gtk/h225_counter.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/gtk/h225_counter.c b/gtk/h225_counter.c
index d9536f3d5c..447fac787d 100644
--- a/gtk/h225_counter.c
+++ b/gtk/h225_counter.c
@@ -1,5 +1,5 @@
/* h225_counter.c
* h225 message counter for ethereal
* Copyright 2003 Lars Roland
*
* $Id$
@@ -520,7 +520,7 @@ gtk_h225counter_init(const char *optarg, void *userdata _U_)
h225counter_reset(hs);
- hs->win=window_new(GTK_WINDOW_TOPLEVEL, "Ethereal: H225 counters");
+ hs->win=window_new(GTK_WINDOW_TOPLEVEL, "Wireshark: H.225 counters");
gtk_window_set_default_size(GTK_WINDOW(hs->win), 400, 200);
hs->vbox=gtk_vbox_new(FALSE, 3);
@@ -1,5 +1,5 @@
/* h225_counter.c
- * h225 message counter for ethereal
+ * H.225 message counter for Wireshark
* Copyright 2003 Lars Roland
*